==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/pt_BR.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Carregando pré-visualização...",
    "Saved" : "Salva",
    "Admin" : "Administrador",
    "a safe home for all your data" : "um lugar seguro para seus dados",
    "Name cannot be empty" : "O nome não pode ficar em branco",
    "The given name is too long" : "O nome é muito longo",
    "The given web address is too long" : "O endereço web fornecido é muito longo",
    "The given legal notice address is too long" : "O endereço do aviso legal é muito longo",
    "The given privacy policy address is too long" : "O endereço da política de privacidade é muito longo",
    "The given slogan is too long" : "O slogan dado é muito longo",
    "The given color is invalid" : "A cor fornecida é inválida",
    "The file was uploaded" : "O arquivo foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O arquivo enviado excede a diretiva upload_max_filesize do php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O arquivo enviado excede a diretiva MAX_FILE_SIZE especificada no formulário HTML",
    "The file was only partially uploaded" : "O aquivo foi parcialmente enviado",
    "No file was uploaded" : "Nenhum arquivo foi enviado",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Could not write file to disk" : "Não foi possível escrever no disco",
    "A PHP extension stopped the file upload" : "Uma extensão PHP parou o envio do arquivo",
    "No file uploaded" : "Nenhum arquivo enviado",
    "Unsupported image type" : "Tipo de imagem não suportado",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Você já está usando um tema personalizado. As configurações do aplicativo Theming podem ser sobrescritas por isso.",
    "Theming" : "Personalização",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidade",
    "Adjust the Nextcloud theme" : "Ajustar o tema do Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Criar e alterar temas torna possível personalizar facilmente o Nextcloud e clientes suportados. Isso será visível para todos os usuários.",
    "Name" : "Nome",
    "Reset to default" : "Redefinir para o padrão",
    "Web link" : "Link web",
    "https://…" : "https://...",
    "Slogan" : "Slogan",
    "Color" : "Cor",
    "Logo" : "Logotipo",
    "Upload new logo" : "Enviar novo logotipo",
    "Login image" : "Imagem de login",
    "Upload new login background" : "Enviar nova imagem de fundo para o login",
    "Remove background image" : "Excluir a imagem de fundo",
    "Advanced options" : "Opções avançadas",
    "Legal notice link" : "Link do aviso legal",
    "Privacy policy link" : "Link da política de privacidade",
    "Header logo" : "Logotipo de cabeçalho",
    "Upload new header logo" : "Enviar novo logotipo de cabeçalho",
    "Favicon" : "Ícone de favoritos",
    "Upload new favicon" : "Enviar novo ícone de favorito",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensão PHP Imagemagick com suporte a imagens SVG para gerar favicons automaticamente, com base no logotipo e na cor enviados."
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-20.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/pt_BR.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Carregando pré-visualização...",
    "Saved" : "Salva",
    "Admin" : "Administrador",
    "a safe home for all your data" : "um lugar seguro para seus dados",
    "Name cannot be empty" : "O nome não pode ficar em branco",
    "The given name is too long" : "O nome é muito longo",
    "The given web address is too long" : "O endereço web fornecido é muito longo",
    "The given web address is not a valid URL" : "O endereço web não é uma URL válida",
    "The given legal notice address is too long" : "O endereço do aviso legal é muito longo",
    "The given legal notice address is not a valid URL" : "O endereço do aviso legal não é uma URL válida",
    "The given privacy policy address is too long" : "O endereço da política de privacidade é muito longo",
    "The given privacy policy address is not a valid URL" : "O endereço da política de privacidade não é uma URL válida",
    "The given slogan is too long" : "O slogan dado é muito longo",
    "The given color is invalid" : "A cor fornecida é inválida",
    "The file was uploaded" : "O arquivo foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O arquivo enviado excede a diretiva upload_max_filesize do php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O arquivo enviado excede a diretiva MAX_FILE_SIZE especificada no formulário HTML",
    "The file was only partially uploaded" : "O aquivo foi parcialmente enviado",
    "No file was uploaded" : "Nenhum arquivo foi enviado",
    "Missing a temporary folder" : "Falta uma pasta temporária",
    "Could not write file to disk" : "Não foi possível escrever no disco",
    "A PHP extension stopped the file upload" : "Uma extensão PHP parou o envio do arquivo",
    "No file uploaded" : "Nenhum arquivo enviado",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Você já está usando um tema personalizado. As configurações do aplicativo Theming podem ser sobrescritas por isso.",
    "Theming" : "Personalização",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidade",
    "Adjust the Nextcloud theme" : "Ajustar o tema do Nextcloud",
    "Open documentation" : "Abrir documentação",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Criar e alterar temas torna possível personalizar facilmente o Nextcloud e clientes suportados. Isso será visível para todos os usuários.",
    "Name" : "Nome",
    "Reset to default" : "Redefinir para o padrão",
    "Web link" : "Link web",
    "https://…" : "https://...",
    "Slogan" : "Slogan",
    "Color" : "Cor",
    "Logo" : "Logotipo",
    "Upload new logo" : "Enviar novo logotipo",
    "Login image" : "Imagem de login",
    "Upload new login background" : "Enviar nova imagem de fundo para o login",
    "Remove background image" : "Excluir a imagem de fundo",
    "Advanced options" : "Opções avançadas",
    "Legal notice link" : "Link do aviso legal",
    "Privacy policy link" : "Link da política de privacidade",
    "Header logo" : "Logotipo de cabeçalho",
    "Upload new header logo" : "Enviar novo logotipo de cabeçalho",
    "Favicon" : "Ícone de favoritos",
    "Upload new favicon" : "Enviar novo ícone de favorito",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensão PHP Imagemagick com suporte a imagens SVG para gerar favicons automaticamente, com base no logotipo e na cor enviados.",
    "Unsupported image type" : "Tipo de imagem não suportado"
},
"nplurals=2; plural=(n > 1);");
